@@ -431,7 +431,7 @@ class Action:
         )
 
     def getGroupFileURL(self, group: int, fileID: str) -> dict:
-        """获取好友文件链接
+        """获取群文件链接
         :param group: 群号
         :param fileID: 文件 ID，可由上报的消息中获得
         """
@@ -541,6 +541,13 @@ class Action:
             raise Exception("fileURL, fileBase64, filePath 必须给定其中一个")
         return self.post("SendMsgV2", payload)
 
+    def openRedBag(self, redBagInfo: dict):
+        """打开红包
+
+        :param redBagInfo: 红包信息, ctx.RedBaginfo
+        """
+        return self.post("OpenRedBag", redBagInfo)
+
     ############获取############
     def getCookies(self) -> dict:
         """获取QQ相关cookie"""
