@@ -187,11 +187,13 @@ class Session(SessionBase):
             return self.action.sendFriendText(self.ctx.FromUin, text)
         return self.action.sendGroupText(self.ctx.FromGroupId, text)
 
-    def send_pic(self, url: str = "", base64: str = "", md5: str = "", text: str = ""):
+    def send_pic(
+        self, url: str = "", base64: str = "", md5s: List[str] = [], text: str = ""
+    ):
         """发送session图片消息
         :param url: 图片URL
         :param base64: 图片base64
-        :param md5: 图片MD5
+        :param md5s: 图片MD5
         :param text: 图片附带文字
         """
         if isinstance(self.ctx, FriendMsg):
@@ -199,14 +201,14 @@ class Session(SessionBase):
                 self.ctx.FromUin,
                 picUrl=url,
                 picBase64Buf=base64,
-                fileMd5=md5,
+                picMd5s=md5s,
                 content=text,
             )
         return self.action.sendGroupPic(
             self.ctx.FromGroupId,
             picUrl=url,
             picBase64Buf=base64,
-            fileMd5=md5,
+            picMd5s=md5s,
             content=text,
         )
 
@@ -255,19 +257,23 @@ class Session(SessionBase):
         self,
         candidates: List[T],
         retry_times: int = 1,
+        key: Callable[[T], Any] = None,
         always_prompt: bool = True,
         timeout: int = 30,
     ) -> Optional[Tuple[T, int]]:
         """提示用户发送序号选择列表中的一项,
-        返回值是一个元组，第一项为选择项，第二项为选择项的索引. 超过重试次数，返回None
+        返回值是一个元组，第一项为选择项，第二项为选择项的索引. 超过重试次数或超时，返回None
 
         :param candidates: 选项列表
         :param retry_times: 获取重试次数
+        :param key: 一个函数，参数为候选列表中项，返回的值将用于发送给用户的提示信息, 默认为`str`
         :param always_prompt: 重试时是否再次发送提示
         :param timeout: 单次获取等待超时时间(秒)
         """
-        msg = "发送对应序号选择一项\n" + "\n".join(
-            [f"【{idx}】 {candidate}" for idx, candidate in enumerate(candidates, 1)]
+        key = key or str
+        items = (key(candidate) for candidate in candidates)
+        msg = f"发送对应序号选择一项({retry_times}次机会, 每次你都只有{timeout}秒的选择时间)\n" + "\n".join(
+            [f"【{idx}】 {item}" for idx, item in enumerate(items, 1)]
         )
         self.send_text(msg)
 
@@ -278,15 +284,17 @@ class Session(SessionBase):
                 prompt = None
             else:
                 prompt = msg if always_prompt else None
+
             what: str = self.want(str(uuid4()), prompt, pop=True, timeout=timeout)
+            if what is None:
+                return
             try:
                 idx = int(what) - 1
+                assert idx >= 0
                 return candidates[idx], idx
             except Exception:
                 self.send_text("序号错误")
 
-        return None
-
 
 class SessionController:
     def __init__(self, session_expiration: int = None):
